@@ -16,6 +16,7 @@ __author__ = 'HPE'
 
 from sushy.resources import base
 
+from proliantutils import exception
 from proliantutils import log
 
 LOG = log.get_logger(__name__)
@@ -35,6 +36,15 @@ class SecurityParams(base.ResourceBase):
     description = base.Field('Description')
     recommended_action = base.Field('RecommendedAction')
 
+    def update_security_param_ignore_status(self, ignore):
+        if not isinstance(ignore, bool):
+            msg = ('The parameter "%(parameter)s" value "%(value)s" is '
+                   'invalid. Valid values are: True/False.' %
+                   {'parameter': 'ignore', 'value': ignore})
+            raise exception.InvalidInputError(msg)
+        data = {"Ignore": ignore}
+        self._conn.patch(self.path, data=data)
+
 
 class SecurityParamsCollection(base.ResourceCollectionBase):
 
