@@ -13,9 +13,11 @@
 # under the License.
 
 import sys
+from unittest import mock
 
-import mock
 from oslo_utils import importutils
+import six
+
 
 ironic_python_agent = importutils.try_import('ironic_python_agent')
 if not ironic_python_agent:
@@ -26,4 +28,4 @@ if not ironic_python_agent:
     ipa_mock.hardware.GenericHardwareManager = mock.MagicMock
     mock.MagicMock.erase_devices = mock.MagicMock(name='erase_devices')
     if 'proliantutils.ipa_hw_manager' in sys.modules:
-        reload(sys.modules['proliantutils.ipa_hw_manager'])
+        six.moves.reload_module('proliantutils.ipa_hw_manager')
